pub struct Tool {
pub tool_type: String,
pub function: FunctionTool,
}Expand description
Represents a tool that can be used in chat
Fields
tool_type: StringThe type of tool (e.g. “function”)
function: FunctionToolThe function definition if this is a function tool