Centralized HTTP response handling for provider backends. Centralized HTTP response handling for LLM provider backends.
The status-code mapping logic
([map_http_status_to_error][crate::http::map_http_status_to_error] and
[parse_retry_after_value][crate::http::parse_retry_after_value]) is target-independent
and is reused by both the native reqwest transport and the WASI Preview2 transport.
The reqwest::Response-based entry point ([ensure_success][crate::http::ensure_success])
and its integration tests are only compiled on non-wasm32 targets.